==> c8y_api-1.6.2.tar.gz: c8y_api-1.6.2/c8y_api/model/__init__.py <==
# Copyright (c) 2020 Software AG,
# Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA,
# and/or its subsidiaries and/or its affiliates and/or their licensors.
# Use, reproduction, transfer, publication or disclosure is prohibited except
# as specifically provided for in your License Agreement with Software AG.

from c8y_api.model.administration import *
from c8y_api.model.applications import *
from c8y_api.model.alarms import *
from c8y_api.model.binaries import *
from c8y_api.model.events import *
from c8y_api.model.identity import *
from c8y_api.model.inventory import *
from c8y_api.model.managedobjects import *
from c8y_api.model.measurements import *
from c8y_api.model.notification2 import *
from c8y_api.model.operations import *

__all__ = ['administration', 'inventory', 'measurements', 'events',
           'User', 'GlobalRole', 'InventoryRole', 'Users', 'GlobalRoles', 'InventoryRoles', 'InventoryRoleAssignment',
           'Permission', 'ReadPermission', 'WritePermission', 'AnyPermission',
           'Application',
           'ManagedObject', 'Device', 'DeviceGroup', 'Fragment', 'NamedObject',
           'Inventory', 'DeviceInventory', 'DeviceGroupInventory',
           'Identity', 'ExternalId', 'Binary', 'Binaries',
           'Measurement', 'Measurements', 'Value', 'Count', 'Grams', 'Kilograms', 'Kelvin', 'Celsius',
           'Event', 'Events', 'Alarm', 'Alarms',
           'Subscription', 'Subscriptions', 'Tokens',
           'Meters', 'Centimeters', 'Liters', 'CubicMeters']

==> c8y_api-1.9.1.tar.gz: c8y_api-1.9.1/c8y_api/model/__init__.py <==
# Copyright (c) 2020 Software AG,
# Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA,
# and/or its subsidiaries and/or its affiliates and/or their licensors.
# Use, reproduction, transfer, publication or disclosure is prohibited except
# as specifically provided for in your License Agreement with Software AG.

from c8y_api.model.administration import *
from c8y_api.model.applications import *
from c8y_api.model.alarms import *
from c8y_api.model.audit import *
from c8y_api.model.binaries import *
from c8y_api.model.events import *
from c8y_api.model.identity import *
from c8y_api.model.inventory import *
from c8y_api.model.managedobjects import *
from c8y_api.model.measurements import *
from c8y_api.model.notification2 import *
from c8y_api.model.operations import *

__all__ = ['administration', 'inventory', 'measurements', 'events',
           'User', 'GlobalRole', 'InventoryRole', 'Users', 'GlobalRoles', 'InventoryRoles', 'InventoryRoleAssignment',
           'Permission', 'ReadPermission', 'WritePermission', 'AnyPermission',
           'Application',
           'AuditRecord', 'AuditRecords',
           'Operation', 'BulkOperation', 'Operations', 'BulkOperations',
           'ManagedObject', 'Device', 'DeviceGroup', 'Availability', 'Fragment', 'NamedObject',
           'Inventory', 'DeviceInventory', 'DeviceGroupInventory',
           'Identity', 'ExternalId', 'Binary', 'Binaries',
           'Measurement', 'Measurements', 'Series', 'Units',
           'Value', 'Count', 'Grams', 'Kilograms', 'Kelvin', 'Celsius', 'Percentage',
           'Event', 'Events', 'Alarm', 'Alarms',
           'Subscription', 'Subscriptions', 'Tokens',
           'Meters', 'Centimeters', 'Liters', 'CubicMeters']
